@@ -1,15 +1,15 @@
 from typing import Dict, List, Optional
 
-from msgspec import Struct
+from valo_api.utils.dict_struct import DictStruct
 
 
-class Error(Struct):
+class Error(DictStruct):
     code: Optional[int] = None
     message: Optional[str] = None
     details: Optional[str] = None
 
 
-class ErrorResponse(Struct):
+class ErrorResponse(DictStruct):
     status: Optional[int] = None
     errors: Optional[List[Error]] = None
     headers: Optional[Dict[str, str]] = None
